@@ -12,14 +12,15 @@ use strict;
 use warnings;
 
 package Pod::Markdown;
-# git description: v3.004-0-g69a7b15
+# git description: v3.300-3-gb01c18d
 
 our $AUTHORITY = 'cpan:RWSTAUNER';
 # ABSTRACT: Convert POD to Markdown
-$Pod::Markdown::VERSION = '3.005';
+$Pod::Markdown::VERSION = '3.400';
 use Pod::Simple 3.27 (); # detected_encoding and keep_encoding bug fix
 use parent qw(Pod::Simple::Methody);
 use Encode ();
+use URI::Escape ();
 
 our %URL_PREFIXES = (
   sco      => 'http://search.cpan.org/perldoc?',
@@ -28,6 +29,9 @@ our %URL_PREFIXES = (
 );
 $URL_PREFIXES{perldoc} = $URL_PREFIXES{metacpan};
 
+our $LOCAL_MODULE_RE = qr/^(Local::|\w*?_\w*)/;
+
+## no critic
 #{
   our $HAS_HTML_ENTITIES;
 
@@ -86,6 +90,7 @@ $URL_PREFIXES{perldoc} = $URL_PREFIXES{metacpan};
   my $DEFAULT_ENTITY_CHARS = '^\n\r\t !\#\$%\(-;=?-~';
 
 #}
+## use critic
 
 # Use hash for simple "exists" check in `new` (much more accurate than `->can`).
 my %attributes = map { ($_ => 1) }
@@ -93,11 +98,14 @@ my %attributes = map { ($_ => 1) }
     html_encode_chars
     match_encoding
     output_encoding
+    local_module_re
+    local_module_url_prefix
     man_url_prefix
     perldoc_url_prefix
     perldoc_fragment_format
     markdown_fragment_format
     include_meta_tags
+    escape_url
   );
 
 
@@ -109,6 +117,16 @@ sub new {
   $self->preserve_whitespace(1);
   $self->nbsp_for_S(1);
   $self->accept_targets(qw( markdown html ));
+  $self->escape_url(1);
+
+  # Default to the global, but allow it to be overwritten in args.
+  $self->local_module_re($LOCAL_MODULE_RE);
+
+  for my $type ( qw( perldoc man ) ){
+    my $attr  = $type . '_url_prefix';
+    # Initialize to the alias.
+    $self->$attr($type);
+  }
 
   while( my ($attr, $val) = each %args ){
     # NOTE: Checking exists on a private var means we don't allow Pod::Simple
@@ -130,20 +148,30 @@ sub new {
     $self->$attr($val);
   }
 
-    # TODO: move this logic to setter (and call _prepare_fragment_format).
-    for my $type ( qw( perldoc man ) ){
-        my $attr  = $type . '_url_prefix';
-        # Use provided argument or default alias.
-        my $url = $self->$attr || $type;
-        # Expand alias if defined (otherwise use url as is).
-        $self->$attr( $URL_PREFIXES{ $url } || $url );
-    }
+  # TODO: call from the setters.
+  $self->_prepare_fragment_formats;
 
-    $self->_prepare_fragment_formats;
+  if(defined $self->local_module_url_prefix && $self->local_module_url_prefix eq '' && !$self->escape_url) {
+    warn("turning escape_url with an empty local_module_url_prefix is not recommended as relative URLs could be confused for IPv6 addresses");
+  }
 
   return $self;
 }
 
+for my $type ( qw( local_module perldoc man ) ){
+  my $attr  = $type . '_url_prefix';
+  no strict 'refs'; ## no critic
+  *$attr = sub {
+    my $self = shift;
+    if (@_) {
+      $self->{$attr} = $URL_PREFIXES{ $_[0] } || $_[0];
+    }
+    else {
+      return $self->{$attr};
+    }
+  }
+}
+
 ## Attribute accessors ##
 
 
@@ -1030,11 +1058,19 @@ sub format_perldoc_url {
   my ($self, $name, $section) = @_;
 
   my $url_prefix = $self->perldoc_url_prefix;
+  if (
+    defined($name)
+    && $self->is_local_module($name)
+    && defined($self->local_module_url_prefix)
+  ) {
+    $url_prefix = $self->local_module_url_prefix;
+  }
+
   my $url = '';
 
   # If the link is to another module (external link).
   if ($name) {
-    $url = $url_prefix . $name;
+    $url = $url_prefix . ($self->escape_url ? URI::Escape::uri_escape($name) : $name);
   }
 
   # See https://rt.cpan.org/Ticket/Display.html?id=57776
@@ -1146,6 +1182,13 @@ sub format_fragment_pod_simple_html {
 sub format_fragment_metacpan { shift->format_fragment_pod_simple_xhtml(@_); }
 sub format_fragment_sco      { shift->format_fragment_pod_simple_html(@_);  }
 
+
+sub is_local_module {
+  my ($self, $name) = @_;
+
+  return ($name =~ $self->local_module_re);
+}
+
 1;
 
 __END__
@@ -1156,8 +1199,8 @@ __END__
 
 =for :stopwords Marcel Gruenauer Victor Moral Ryan C. Thompson <rct at thompsonclan d0t
 org> Aristotle Pagaltzis Randy Stauner ACKNOWLEDGEMENTS html cpan
-testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto
-metadata placeholders metacpan
+testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata
+placeholders metacpan
 
 =head1 NAME
 
@@ -1165,7 +1208,7 @@ Pod::Markdown - Convert POD to Markdown
 
 =head1 VERSION
 
-version 3.005
+version 3.400
 
 =for test_synopsis my ($pod_string);
 
@@ -1235,6 +1278,22 @@ The constructor accepts the following named arguments:
 
 =item *
 
+C<local_module_url_prefix>
+
+Alters the perldoc urls that are created from C<< LE<lt>E<gt> >> codes
+when the module is a "local" module (C<"Local::*"> or C<"Foo_Corp::*"> (see L<perlmodlib>)).
+
+The default is to use C<perldoc_url_prefix>.
+
+=item *
+
+C<local_module_re>
+
+Alternate regular expression for determining "local" modules.
+Default is C<< our $LOCAL_MODULE_RE = qr/^(Local::|\w*?_\w*)/ >>.
+
+=item *
+
 C<man_url_prefix>
 
 Alters the man page urls that are created from C<< LE<lt>E<gt> >> codes.
@@ -1328,6 +1387,14 @@ C<include_meta_tags>
 Specifies whether or not to print author/title meta tags at the top of the document.
 Default is false.
 
+=item *
+
+C<escape_url>
+
+Specifies whether or not to escape URLs.  Default is true.  It is not recommended
+to turn this off with an empty local_module_url_prefix, as the resulting local
+module URLs can be confused with IPv6 addresses by web browsers.
+
 =back
 
 =head2 html_encode_chars
@@ -1386,6 +1453,14 @@ The encoding to use when writing to the output file handle.
 If neither this nor L</match_encoding> are specified,
 a character string will be returned in whatever L<Pod::Simple> output method you specified.
 
+=head2 local_module_re
+
+Returns the regular expression used to determine local modules.
+
+=head2 local_module_url_prefix
+
+Returns the url prefix in use for local modules.
+
 =head2 man_url_prefix
 
 Returns the url prefix in use for man pages.
@@ -1409,6 +1484,11 @@ to an internal section in this document.
 Returns the boolean value indicating
 whether or not meta tags will be printed.
 
+=head2 escape_url
+
+Returns the boolean value indicating
+whether or not URLs should be escaped.
+
 =head2 format_man_url
 
 Used internally to create a url (using L</man_url_prefix>)
@@ -1455,6 +1535,10 @@ Format fragment for L<metacpan.org>
 Format fragment for L<search.cpan.org>
 (uses L</format_fragment_pod_simple_html>).
 
+=head2 is_local_module
+
+Uses C<local_module_re> to determine if passed module is a "local" module.
+
 =for Pod::Coverage parse_from_file
 parse_from_filehandle
 
@@ -1512,7 +1596,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/Pod-Markdown>
+L<https://metacpan.org/release/Pod-Markdown>
 
 =back
 
@@ -1557,7 +1641,7 @@ Randy Stauner <rwstauner@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Aristotle Pagaltzis Cindy Wang (CindyLinz) Graham Ollis Mike Covington motemen moznion Peter Vereshagin Ryan C. Thompson Yasutaka ATARASHI
+=for stopwords Aristotle Pagaltzis Cindy Wang (CindyLinz) Graham Ollis Johannes Schauer Marin Rodrigues Mike Covington motemen moznion Peter Vereshagin Ryan C. Thompson Yasutaka ATARASHI
 
 =over 4
 
@@ -1575,6 +1659,10 @@ Graham Ollis <plicease@cpan.org>
 
 =item *
 
+Johannes Schauer Marin Rodrigues <josch@mister-muffin.de>
+
+=item *
+
 Mike Covington <mfcovington@gmail.com>
 
 =item *
